abacusai.mcp_server_connection — AbacusAI documentation

# abacusai.mcp_server_connection

## Classes

`McpServerConnection` | Model Context Protocol Server Connection

## Module Contents

class abacusai.mcp_server_connection.McpServerConnection(client, mcpServerConnectionId=None, createdAt=None, updatedAt=None, name=None, config=None, description=None, transport=None, authType=None, externalConnectionId=None, inactive=None, tools=None, errorMsg=None, metadata=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Model Context Protocol Server Connection

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - mcpServerConnectionId (id) – the id of the MCP server connection.

    - createdAt (str) – the date and time the MCP server connection was created.

    - updatedAt (str) – the date and time the MCP server connection was updated.

    - name (str) – The name of the MCP server.

    - config (dict) – a dictionary containing the config for the MCP server.

    - description (str) – description of what the MCP server does.

    - transport (str) – the transport type for the MCP server.

    - authType (str) – the auth type for the MCP server.

    - externalConnectionId (id) – the external connection id for the MCP server.

    - inactive (bool) – whether the MCP server is inactive.

    - tools (list) – the tools for the MCP server.

    - errorMsg (str) – the error message for the MCP server.

    - metadata (dict) – the metadata for the MCP server.

  mcp_server_connection_id = None
  created_at = None
  updated_at = None
  name = None
  config = None
  description = None
  transport = None
  auth_type = None
  external_connection_id = None
  inactive = None
  tools = None
  error_msg = None
  metadata = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict